@@ -34,3 +34,8 @@ def merge2excel(dir_path, output_file='merge2excel.xlsx'):
 @except_dec()
 def sheet2excel(file_path):
     mainExcel.sheet2excel(file_path)
+
+
+@except_dec()
+def merge2sheet(dir_path, output_sheet_name: str = 'Sheet1', output_excel_name: str = 'merge2sheet'):
+    mainExcel.merge2sheet(dir_path, output_sheet_name, output_excel_name)
