@@ -82,8 +82,10 @@ class MainPDF():
         pdf.close()
 
     def pdf2imgs(self, pdf_path: str, out_dir=".") -> None:
-
+        print('PDF开始转换，你可以加入交流群唠唠嗑：http://www.python4office.cn/wechat-group/')
         pdfDoc = fitz.open(pdf_path)
+        if pdfDoc.pageCount > 50:
+            print('少年，你的PDF页数有点多哟，请耐心等待~')
         for pg in range(pdfDoc.pageCount):
             page = pdfDoc[pg]
             rotate = int(0)
@@ -98,3 +100,4 @@ class MainPDF():
                 os.makedirs(out_dir)  # 若图片文件夹不存在就创建
 
             pix.writePNG(out_dir + '/' + 'images_%s.png' % pg)  # 将图片写入指定的文件夹内
+        print(f'PDF转换Image完成，图片在你指定的output文件夹{out_dir}，如果没有指定，默认是PDF同一个文件夹')
